==> nextcloud-app-mail-0.20.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/es_CR.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Correo",
    "Auto detect failed. Please use manual mode." : "Se presentó una falla en la auto detección. Por favor usa el modo manual.",
    "Updating account failed: " : "Se presentó una falla al actualizar la cuenta",
    "Creating account failed: " : "Se presentó una falla al crear la cuenta:",
    "Name" : "Nombre",
    "Mail Address" : "Dirección de Correo",
    "Password" : "Contraseña",
    "IMAP Host" : "Servidor IMAP",
    "None" : "Ninguno",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Puerto IMAP",
    "IMAP User" : "Usuario IMAP",
    "IMAP Password" : "Contraseña IMAP",
    "SMTP Host" : "Servior SMTP",
    "SMTP Port" : "Puerto SMTP",
    "SMTP User" : "Usuario SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Connect" : "Conectar",
    "Add mail account" : "Agregar cuenta de correo",
    "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Subject" : "Asunto",
    "Upload attachment" : "Cargar adjunto",
    "Add attachment from Files" : "Agregar adjunto desd Archivos",
    "Sending …" : "Enviando ...",
    "Message sent!" : "¡Mensaje enviado!",
    "Send" : "Enviar",
    "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
    "No messages in this folder" : "No hay mensajes en esta carpeta",
    "Delete" : "Borrar",
    "Could not load your message" : "No fue posible cargar tu mensaje",
    "Import into calendar" : "Importar al calendario",
    "Download attachment" : "Descargar adjunto",
    "Save to Files" : "Guardar a Archivos",
    "Choose a folder to store the attachment in" : "Seleccciona la carpeta en la cual almacenar el adjunto",
    "Save all to Files" : "Guardar todo a Archivos",
    "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
    "New message" : "Mensaje nuevo",
    "Settings" : "Configuraciones ",
    "Show all folders" : "Mostrar todas las carpetas",
    "Collapse folders" : "Compactar carpetas",
    "Speed up your Mail experience with these quick shortcuts." : "Haz más rápida tu experiencia de Correo con estos atajos rápidos. ",
    "Compose new message" : "Escribir mensaje nuevo",
    "Newer message" : "Mensaje más nuevo",
    "Older message" : "Mensaje más antiguo",
    "Toggle star" : "Alternar favoritos",
    "Toggle unread" : "Alternar no leídos",
    "Search" : "Buscar",
    "Refresh" : "Actualizar",
    "Connect your mail account" : "Conecta tu cuenta de correo",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n mensaje nuevo \nde {from}","%n mensajes nuevos \nde {from}"],
    "Nextcloud Mail" : "Correo Nextcloud",
    "Could not load {tag}{name}{endtag}" : "No fue posible cargar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Se presentó un problema al cargar  {tag}{name}{endtag}",
    "Could not load the desired message" : "No fue posible cargar el mensaje deseado",
    "Could not load the message" : "No fue posible cargar el mensaje",
    "Error loading message" : "Se presentó un error al cargar el mensaje",
    "Forwarding to %s" : "Reenviando a %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Haz click aqui si no eres redireccionado automáticamente dentro de los siguietes segundos. ",
    "Redirect" : "Redireccionar",
    "The link leads to %s" : "La liga lleva a %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si no quieres visitar esa página, puedes regresar a <a href=\"%s\">Correo</a>.",
    "Continue to %s" : "Continuar a %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-1.1.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/es_CR.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Correo",
    "Auto detect failed. Please use manual mode." : "Se presentó una falla en la auto detección. Por favor usa el modo manual.",
    "Updating account failed: " : "Se presentó una falla al actualizar la cuenta",
    "Creating account failed: " : "Se presentó una falla al crear la cuenta:",
    "Name" : "Nombre",
    "Mail Address" : "Dirección de Correo",
    "Password" : "Contraseña",
    "IMAP Host" : "Servidor IMAP",
    "None" : "Ninguno",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Puerto IMAP",
    "IMAP User" : "Usuario IMAP",
    "IMAP Password" : "Contraseña IMAP",
    "SMTP Host" : "Servior SMTP",
    "SMTP Port" : "Puerto SMTP",
    "SMTP User" : "Usuario SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Save" : "Guardar",
    "Connect" : "Conectar",
    "Add mail account" : "Agregar cuenta de correo",
    "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Select account" : "Selecciona la cuenta",
    "Subject" : "Asunto",
    "Upload attachment" : "Cargar adjunto",
    "Add attachment from Files" : "Agregar adjunto desd Archivos",
    "Sending …" : "Enviando ...",
    "Go back" : "Regresar",
    "Retry" : "Reintentar",
    "Message sent!" : "¡Mensaje enviado!",
    "Send" : "Enviar",
    "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
    "No messages in this folder" : "No hay mensajes en esta carpeta",
    "Mark read" : "Marcar como leído",
    "Delete" : "Borrar",
    "Reply" : "Responder",
    "Forward" : "Adelante",
    "Could not load your message" : "No fue posible cargar tu mensaje",
    "Import into calendar" : "Importar al calendario",
    "Download attachment" : "Descargar adjunto",
    "Save to Files" : "Guardar a Archivos",
    "Choose a folder to store the attachment in" : "Seleccciona la carpeta en la cual almacenar el adjunto",
    "Save all to Files" : "Guardar todo a Archivos",
    "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
    "New message" : "Mensaje nuevo",
    "Settings" : "Configuraciones ",
    "Delete account" : "Borrar cuenta",
    "Show all folders" : "Mostrar todas las carpetas",
    "Collapse folders" : "Compactar carpetas",
    "Mark all as read" : "Marcar todos como leídos",
    "Signature" : "Firma",
    "General" : "General",
    "User" : "Usuario",
    "Host" : "Servidor",
    "Port" : "Puerto",
    "Speed up your Mail experience with these quick shortcuts." : "Haz más rápida tu experiencia de Correo con estos atajos rápidos. ",
    "Compose new message" : "Escribir mensaje nuevo",
    "Newer message" : "Mensaje más nuevo",
    "Older message" : "Mensaje más antiguo",
    "Toggle star" : "Alternar favoritos",
    "Toggle unread" : "Alternar no leídos",
    "Search" : "Buscar",
    "Refresh" : "Actualizar",
    "Connect your mail account" : "Conecta tu cuenta de correo",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n mensaje nuevo \nde {from}","%n mensajes nuevos \nde {from}"],
    "Nextcloud Mail" : "Correo Nextcloud",
    "Could not load {tag}{name}{endtag}" : "No fue posible cargar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Se presentó un problema al cargar  {tag}{name}{endtag}",
    "Could not load the desired message" : "No fue posible cargar el mensaje deseado",
    "Could not load the message" : "No fue posible cargar el mensaje",
    "Error loading message" : "Se presentó un error al cargar el mensaje",
    "Forwarding to %s" : "Reenviando a %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Haz click aqui si no eres redireccionado automáticamente dentro de los siguietes segundos. ",
    "Redirect" : "Redireccionar",
    "The link leads to %s" : "La liga lleva a %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si no quieres visitar esa página, puedes regresar a <a href=\"%s\">Correo</a>.",
    "Continue to %s" : "Continuar a %s"
},
"nplurals=2; plural=(n != 1);");
